package VMOMI::HostImageAcceptanceLevel;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
